@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.  You may
@@ -99,7 +99,8 @@ typedef enum
   MagickGradientOptions,
   MagickWeightOptions,
   MagickComplianceOptions,
-  MagickAutoThresholdOptions
+  MagickAutoThresholdOptions,
+  MagickPagesizeOptions
 } CommandOption;
 
 typedef enum
