@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.  You may
@@ -104,7 +104,6 @@ extern ModuleExport size_t
   RegisterMNGImage(void),
   RegisterMONOImage(void),
   RegisterMPCImage(void),
-  RegisterMPEGImage(void),
   RegisterMPRImage(void),
   RegisterMSLImage(void),
   RegisterMTVImage(void),
@@ -174,6 +173,7 @@ extern ModuleExport size_t
   RegisterVDAImage(void),
   RegisterVICARImage(void),
   RegisterVIDImage(void),
+  RegisterVIDEOImage(void),
   RegisterVIFFImage(void),
   RegisterVIPSImage(void),
   RegisterVSTImage(void),
@@ -187,7 +187,6 @@ extern ModuleExport size_t
   RegisterXCFImage(void),
   RegisterXPMImage(void),
   RegisterXPSImage(void),
-  RegisterXTRNImage(void),
   RegisterXVImage(void),
   RegisterXWDImage(void),
   RegisterYCBCRImage(void),
@@ -270,7 +269,6 @@ extern ModuleExport void
   UnregisterMNGImage(void),
   UnregisterMONOImage(void),
   UnregisterMPCImage(void),
-  UnregisterMPEGImage(void),
   UnregisterMPRImage(void),
   UnregisterMSLImage(void),
   UnregisterMTVImage(void),
@@ -340,6 +338,7 @@ extern ModuleExport void
   UnregisterVDAImage(void),
   UnregisterVICARImage(void),
   UnregisterVIDImage(void),
+  UnregisterVIDEOImage(void),
   UnregisterVIFFImage(void),
   UnregisterVIPSImage(void),
   UnregisterVSTImage(void),
@@ -353,7 +352,6 @@ extern ModuleExport void
   UnregisterXCFImage(void),
   UnregisterXPMImage(void),
   UnregisterXPSImage(void),
-  UnregisterXTRNImage(void),
   UnregisterXVImage(void),
   UnregisterXWDImage(void),
   UnregisterYCBCRImage(void),
