@@ -30,17 +30,17 @@ extern "C" {
 #define MagickLibVersion  0x69C
 #define MagickLibVersionText  "6.9.12"
 #define MagickLibVersionNumber  7,0,0
-#define MagickLibAddendum  "-63"
+#define MagickLibAddendum  "-76"
 #define MagickLibInterface  7
 #define MagickLibMinInterface  7
-#define MagickPlatform  "x86_64"
+#define MagickPlatform  "i386"
 #define MagickppLibVersionText  "6.9.12"
 #define MagickppLibVersionNumber  9:0:0
-#define MagickppLibAddendum  "-63"
+#define MagickppLibAddendum  "-76"
 #define MagickppLibInterface  9
 #define MagickppLibMinInterface  9
-#define MagickGitRevision  "17457"
-#define MagickReleaseDate  "2022-09-11"
+#define MagickGitRevision  "17694"
+#define MagickReleaseDate  "2023-02-05"
 #define MagickHomeURL  "file:///usr/local/share/doc/ImageMagick/index.html"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
